import os
import time
import re


def get_times():
    walltime = int(86400)
    starttime = int(time.time())
    return walltime, starttime


def save_env(
    wall_time_=None, start_time_=None, environment_file="/etc/condor/walltime.cfg"
):
    """
    Save wall-time information to system variables WALLTIME & BOOTTIME.

    Values by default are stored in /etc/environment, discarding old wall-/boottime entries, preserving the rest.
    """
    if not os.access(environment_file, os.W_OK):
        raise EnvironmentError("Can't write to %s" % environment_file)

    with open(environment_file, mode="rt") as file_:
        # keep results != WALLTIME/BOOTTIME
        content = [
            entry
            for entry in file_.readlines()
            if re.match("(?:MachineMaxWall|MachineStart)time", entry, re.IGNORECASE)
            is None
        ]
        if wall_time_ is not None:
            content.append("MachineMaxWalltime=%d\n" % wall_time_)
        if start_time_ is not None:
            content.append("MachineStarttime=%d\n" % start_time_)
    with open(environment_file, mode="wt") as file_:
        file_.writelines(content)


if __name__ == "__main__":
    try:
        wall_time, start_time = get_times()
        # Condor parses stdout as configuration file content
        print("MachineMaxWalltime=%d" % wall_time)
        print("MachineStarttime=%d" % start_time)
        save_env(wall_time, start_time)
    except (ValueError, EnvironmentError, TypeError):
        # Fall back on reading /proc/uptime
        with open("/proc/uptime", "r") as _file:
            uptime = float(_file.readline().split()[0])
        boot_time = int(time.time() - uptime)
        print("MachineStarttime=%d" % boot_time)
